# Easy_klines
"Easy_klines" is a Python library that provides a solution to the limitations of exchange APIs in retrieving candlestick data more efficiently and quickly.




# Contact
mohder - mohder1379@gmail.com

Project Link: https://github.com/mohder79/Easy_klines
